==> haskell-vault-0.3.1.0-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vault
version: 0.3.1.0
id: vault-0.3.1.0-9ZML0jKNCF8K87yZXt3eZb
key: vault-0.3.1.0-9ZML0jKNCF8K87yZXt3eZb
license: BSD3
copyright: (c) Heinrich Apfelmus 2011-2013
maintainer: Heinrich Apfelmus <apfelmus at quantentunnel de>
homepage: https://github.com/HeinrichApfelmus/vault
synopsis: a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.
    .
    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.
    .
    Also provided is a /locker/ type, representing a store for a single element.
category: Data
author: Heinrich Apfelmus, Elliott Hird
exposed: True
indefinite: False
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict
abi: 9dc4dd1d8e02333780a35dab851fe86b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/vault-0.3.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/vault-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/vault-0.3.1.0
hs-libraries: HSvault-0.3.1.0-9ZML0jKNCF8K87yZXt3eZb
depends:
    base-4.10.1.0 containers-0.5.10.2
    hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    unordered-containers-0.2.9.0-GWvuj0HLmUnDmBShmJCvae
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             unordered-containers-0.2.9.0-GWvuj0HLmUnDmBShmJCvae=b402656649e5f5df6537cabd8124c4af
haddock-interfaces: /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html: /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vault-0.3.1.0-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vault
version: 0.3.1.0
id: vault-0.3.1.0-81QCypRRNkaHzxLwWgOdau
key: vault-0.3.1.0-81QCypRRNkaHzxLwWgOdau
license: BSD3
copyright: (c) Heinrich Apfelmus 2011-2013
maintainer: Heinrich Apfelmus <apfelmus at quantentunnel de>
homepage: https://github.com/HeinrichApfelmus/vault
synopsis: a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.
    .
    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.
    .
    Also provided is a /locker/ type, representing a store for a single element.
category: Data
author: Heinrich Apfelmus, Elliott Hird
exposed: True
indefinite: False
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict
abi: 908b99e386dd6dfcfae3b19596f778c3
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/vault-0.3.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/vault-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/vault-0.3.1.0
hs-libraries: HSvault-0.3.1.0-81QCypRRNkaHzxLwWgOdau
depends:
    base-4.10.1.0 containers-0.5.10.2
    hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
haddock-interfaces: /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html: /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
